import { LLMProvider } from '../../constants/llmProvider';
import { IGraphItem, ILocalTool } from '../../types';
import { AgentStatus, IAgentTool, ISourceNode, INodeSchema, IPGSchema, SourceNodeType, INodeDescription } from '../../types/agents';
import { Base } from '../base';
import { Configuration } from '../Configuration';
import { PromptGroupSessionsList } from '../promptGroups/PromptGroupSessionsList';
import { ToolCall, ToolCallResult } from '../toolCalls';
/**
 * Represents an agent in xpanderAI, managing the tools, sessions, and operations
 * associated with the agent. This class enables loading agents, handling tool executions,
 * and managing prompt group sessions.
 */
export declare class Agent extends Base {
    /** Configuration settings for the agent. */
    configuration: Configuration;
    /** Unique identifier for the agent. */
    id: string;
    /** Organization ID to which the agent belongs. */
    organizationId: string;
    /** Current status of the agent. */
    status: AgentStatus;
    /** Human-readable name of the agent. */
    name: string;
    /** List of source nodes associated with the agent. */
    sourceNodes: ISourceNode[];
    /** Whether prompt group switching is allowed for the agent. */
    pgSwitchAllowed: boolean;
    /** Array of tools available to the agent. */
    tools: IAgentTool[];
    /** Array of graph items related to the agent. */
    graphs: IGraphItem[];
    /** Array of agent tools specific to prompt groups. */
    pgOas: IAgentTool[];
    /** Array of agent tools specific to prompt groups. */
    pgSchemas: IPGSchema[];
    /** Array of agent tools specific to prompt groups. */
    pgNodeDescriptionOverride: INodeDescription[];
    generalInstructions: string;
    judgeInstructions: string;
    /** Indicates whether the agent is ready with tools loaded. */
    ready: boolean;
    /** Collection of local tools specific to this agent. */
    localTools: ILocalTool[];
    /** Manages prompt group sessions for this agent. */
    promptGroupSessions: PromptGroupSessionsList;
    protected oversizedResponseCache: any;
    /** Maps original tool names to renamed versions for consistency. */
    protected originalToolNamesReMapping: Record<string, string>;
    constructor(
    /** Configuration settings for the agent. */
    configuration: Configuration, 
    /** Unique identifier for the agent. */
    id: string, 
    /** Organization ID to which the agent belongs. */
    organizationId: string, 
    /** Current status of the agent. */
    status: AgentStatus, 
    /** Human-readable name of the agent. */
    name: string, 
    /** List of source nodes associated with the agent. */
    sourceNodes: ISourceNode[], 
    /** Whether prompt group switching is allowed for the agent. */
    pgSwitchAllowed?: boolean, 
    /** Array of tools available to the agent. */
    tools?: IAgentTool[], 
    /** Array of graph items related to the agent. */
    graphs?: IGraphItem[], 
    /** Array of agent tools specific to prompt groups. */
    pgOas?: IAgentTool[], 
    /** Whether the agent should automatically load its resources. */
    autoLoad?: boolean, 
    /** Array of agent tools specific to prompt groups. */
    pgSchemas?: IPGSchema[], 
    /** Array of agent tools specific to prompt groups. */
    pgNodeDescriptionOverride?: INodeDescription[], generalInstructions?: string, judgeInstructions?: string);
    /** Checks if the agent is a custom-defined agent. */
    get isCustom(): boolean;
    /**
     * Loads the agent data from the specified source node type.
     * @param sourceNodeType - The type of source node to load.
     */
    load(sourceNodeType?: SourceNodeType): void;
    /**
     * Retrieves tools compatible with the specified LLM provider.
     * @param llmProvider - The LLM provider to filter tools by.
     * @returns A list of tools that match the specified provider.
     */
    getTools(llmProvider?: LLMProvider, returnAllTools?: boolean): any[];
    protected getOversizedResponseTools(llmProvider?: LLMProvider): any[];
    /** Constructs the API URL for this agent. */
    get url(): string;
    /**
     * Adds local tools to the agent with prefixed function names.
     * @param tools - The list of local tools to add.
     */
    addLocalTools(tools: any[] | ILocalTool[]): void;
    /** Checks if the agent has any local tools loaded. */
    get hasLocalTools(): boolean;
    /**
     * Executes a single tool call and returns the result.
     * @param tool - The tool call to execute.
     * @returns The result of the tool execution.
     */
    runTool(tool: ToolCall, payloadExtension?: any): ToolCallResult;
    /**
     * Executes multiple tool calls sequentially and returns their results.
     * @param toolCalls - The list of tool calls to execute.
     * @returns A list of results for each tool execution.
     */
    runTools(toolCalls: ToolCall[], payloadExtension?: any): ToolCallResult[];
    /** Retrieves the type of source node for the agent. */
    get sourceNodeType(): SourceNodeType;
    selectPromptGroup(promptGroupName: string): void;
    /**
     * Retrieves schemas grouped by node name based on the active prompt group session.
     *
     * This method returns an object where each key is a node name, and the value is the corresponding schema.
     * It ensures that schemas are only fetched if there is an active session with a valid `promptGroupId`
     * and if `pgSchemas` is not empty.
     *
     * @returns {Record<string, INodeSchema>} A record of schemas indexed by their node name, or an empty object if conditions are not met.
     */
    schemasByNodeName(): Record<string, INodeSchema>;
    protected runOversizedResponseTool(tool: ToolCall): ToolCallResult;
    retrieveOversizedResponseCache(): any;
    modifyOversizedResponseCache(cache: any): any;
}
